| Title: | Identification of domain isotypes in pfam data |
|---|---|
| Description: | Protein domains is one of the most import annoation of proteins we have with the Pfam database/tool being (by far) the most used tool. This R package enables the user to read the pfam prediction from both webserver and stand-alone runs into R. We have recently shown most human protein domains exist as multiple distinct variants termed domain isotypes. Different domain isotypes are used in a cell, tissue, and disease-specific manner. Accordingly, we find that domain isotypes, compared to each other, modulate, or abolish the functionality of a protein domain. This R package enables the identification and classification of such domain isotypes from Pfam data. |
| Authors: | Kristoffer Vitting-Seerup [cre, aut] (ORCID: <https://orcid.org/0000-0002-6450-0608>) |
| Maintainer: | Kristoffer Vitting-Seerup <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.13.0 |
| Built: | 2026-05-30 07:12:57 UTC |
| Source: | https://github.com/bioc/pfamAnalyzeR |
Determine domain isotype
analyse_pfam_isotypes(pfamRes, fracCutoff = 0.1)analyse_pfam_isotypes(pfamRes, fracCutoff = 0.1)
pfamRes |
A data frame with pfam augmneted with indel and truncation info (as produced by |
fracCutoff |
The fraction of a protein domain that must be affected before classifying it a truncation or indel. |
The data.frame with the Pfam results now augmented with info about domain domain isotype
### Load pfam data pfamResultFile <- system.file("extdata/pfam_results.txt", package = "pfamAnalyzeR") pfamRes <- read_pfam(pfamResultFile) ### Augment the pfam data pfamRes <- augment_pfam(pfamRes) ### Predict domain isotype pfamRes <- analyse_pfam_isotypes(pfamRes)### Load pfam data pfamResultFile <- system.file("extdata/pfam_results.txt", package = "pfamAnalyzeR") pfamRes <- read_pfam(pfamResultFile) ### Augment the pfam data pfamRes <- augment_pfam(pfamRes) ### Predict domain isotype pfamRes <- analyse_pfam_isotypes(pfamRes)
Augment pfam domains with truncation/indel calculations
augment_pfam(pfamRes)augment_pfam(pfamRes)
pfamRes |
A data frame with pfam results as produced by |
The data.frame with the Pfam results now augmented with info on trunkation and indel sizes
### Load pfam data pfamResultFile <- system.file("extdata/pfam_results.txt", package = "pfamAnalyzeR") pfamRes <- read_pfam(pfamResultFile) ### Augment the pfam data pfamRes <- augment_pfam(pfamRes)### Load pfam data pfamResultFile <- system.file("extdata/pfam_results.txt", package = "pfamAnalyzeR") pfamRes <- read_pfam(pfamResultFile) ### Augment the pfam data pfamRes <- augment_pfam(pfamRes)
Read in and analyze pfam domains isotypes
pfamAnalyzeR(path, fracCutoff = 0.1)pfamAnalyzeR(path, fracCutoff = 0.1)
path |
A string indicating the full path to the Pfam result file |
fracCutoff |
The fraction of a protein domain that must be affected before classifying it a truncation or indel. |
The data.frame with the Pfam results now augmented with info about domain structural variation
### Predict domain isotypes in pfam results pfamResultFile <- system.file("extdata/pfam_results.txt", package = "pfamAnalyzeR") pfamRes <- pfamAnalyzeR(pfamResultFile)### Predict domain isotypes in pfam results pfamResultFile <- system.file("extdata/pfam_results.txt", package = "pfamAnalyzeR") pfamRes <- pfamAnalyzeR(pfamResultFile)
Read Pfam result file file into R. Supports both result files from local and web-server
read_pfam(path)read_pfam(path)
path |
A string indicating the full path to the Pfam result file |
The pfam webserver can be found at https://www.ebi.ac.uk/Tools/hmmer/search/hmmscan.
A data.frame with the Pfam results
pfamResultFile <- system.file("extdata/pfam_results.txt", package = "pfamAnalyzeR") pfamRes <- read_pfam(pfamResultFile)pfamResultFile <- system.file("extdata/pfam_results.txt", package = "pfamAnalyzeR") pfamRes <- read_pfam(pfamResultFile)